package com.logicbig.example;

import javax.validation.*;
import javax.validation.constraints.Size;
import javax.validation.executable.ExecutableValidator;
import java.beans.IntrospectionException;
import java.lang.reflect.Method;
import java.util.Set;

public class MethodReturnValidationExample {

    private static class TestBean {
        @Size(min = 5)
        public int[] findNumbers () {
            return new int[]{1, 2, 3};
        }
    }

    public static void main (String[] args) throws NoSuchMethodException, IntrospectionException {
        TestBean test = new TestBean();
        int[] testNumbers = test.findNumbers();

        Method method = TestBean.class.getDeclaredMethod("findNumbers");

        Validator validator = getValidator();
        ExecutableValidator executableValidator = validator.forExecutables();
        Set<ConstraintViolation<TestBean>> violations =
                            executableValidator.validateReturnValue(test,
                                                method, testNumbers);


        if (violations.size() > 0) {
            violations.stream().forEach(MethodReturnValidationExample::printError);
        } else {
            //proceed using Order object
        }
    }

    private static Validator getValidator(){
        Configuration<?> config = Validation.byDefaultProvider().configure();
        ValidatorFactory factory = config.buildValidatorFactory();
        Validator validator = factory.getValidator();
        factory.close();
        return validator;
    }

    private static void printError (
                        ConstraintViolation<TestBean> violation) {
        System.out.println(violation.getPropertyPath() + " " + violation.getMessage());
    }
}